# tomato: au-tomation without pain!

[![Documentation](https://badgen.net/badge/docs/dgbowl.github.io/grey?icon=firefox)](https://dgbowl.github.io/tomato)
[![PyPi version](https://badgen.net/pypi/v/dgpost/?icon=pypi)](https://pypi.org/project/tomato)
![Github link](https://badgen.net/github/tag/dgbowl/tomato/?icon=github)
![Github status](https://badgen.net/github/checks/dgbowl/tomato/?icon=github)

`tomato` is the instrument automation package developed at Empa. Currently supported 
hardware is:

- `dummy`: a Dummy device for testing purposes
- `biologic`: device for BioLogic potentiostats via the EC-Lib library, Windows only.

See the [Documentation](https://dgbowl.github.io/tomato) for more detailed info.

## Contributors:
- [Peter Kraus](http://github.com/PeterKraus)
- [Loris Ercole](http://github.com/lorisercole)

## Acknowledgements

This project has received funding from the European Union’s Horizon 2020 research and innovation programme under grant agreement No 957189. The project is part of BATTERY 2030+, the large-scale European research initiative for inventing the sustainable batteries of the future.
